@@ -18,33 +18,26 @@
 #'
 #' @param cdm A cdm_reference object.
 #' @param name Name of the GeneratedCohortSet
-#' @param conceptSetList Named list of concept sets.
-#' @param summariseMode Choice on how to summarize the exposures. There are
-#' three options:
-#' "FixedTime" each individual is followed the exact same number of days
-#' specified in 'fixedTime' argument.
-#' "AllEras" we summarize the output will be a summary of the exposed eras of
-#' each individual. Each individual can contribute multiple times.
-#' "FirstEra" we only consider the first observable era of each individual. In
-#' this case each individual can not contribute with multiple rows.
-#' By default: "AllEras".
-#' @param fixedTime Time period after first exposure where we summarize the
-#' ingredient of interest. Argument only considered if 'summariseMode' =
-#' "FixedTime". No default value is provided.
-#' @param daysPriorObservation Minimum number of days of prior observation
-#' required for the incident eras to be considered. If NULL its is not required
-#' to be within observation_period.
-#' @param gapEra Number of days between two continuous exposures to be
-#' considered in the same era. By default: 0.
-#' @param priorUseWashout Prior days without exposure. By default: NULL.
-#' @param cohortDateRange Range for cohort_start_date and cohort_end_date
-#' @param imputeDuration Whether/how the duration should be imputed
-#' "eliminate", "median", "mean", "quantile25", "quantile75".
+#' @param conceptSet Named list of concept sets.
 #' @param durationRange Range between the duration must be comprised. It should
 #' be a numeric vector of length two, with no NAs and the first value should be
 #' equal or smaller than the second one. It is only required if imputeDuration
-#' = TRUE. If NULL no restrictions are applied. By default: NULL.
-#'
+#' = TRUE. If NULL no restrictions are applied.
+#' @param imputeDuration Whether/how the duration should be imputed
+#' "none", "median", "mean", "mode", or it can be a count
+#' @param gapEra Number of days between two continuous exposures to be
+#' considered in the same era.
+#' @param priorUseWashout Prior days without exposure.
+#' @param priorObservation Minimum number of days of prior observation
+#' required for the incident eras to be considered. If NULL its is not required
+#' to be within observation_period.
+#' @param cohortDateRange Range for cohort_start_date and cohort_end_date
+#' @param limit Choice on how to summarise the exposures. There are
+#' two options:
+#' "all" we summarise the output will be a summary of the exposed eras of
+#' each individual. Each individual can contribute multiple times.
+#' "first" we only consider the first observable era of each individual that fulfills the criteria provided
+#' in previous parameters. In this case each individual can not contribute with multiple rows.
 #' @return The function returns the 'cdm' object with the created tables as
 #' references of the object.
 #'
@@ -63,56 +56,62 @@
 #' cdm <- generateDrugUtilisationCohortSet(
 #'   cdm = cdm,
 #'   name = "drug_cohorts",
-#'   conceptSetList = druglist,
-#'   daysPriorObservation = 365
+#'   conceptSet = druglist,
+#'   priorObservation = 365
 #' )
 #'
-#' cdm$drug_cohorts
+#' cdm[["drug_cohorts"]]
 #'
-#' cohortSet(cdm$drug_cohorts)
+#' cohortSet(cdm[["drug_cohorts"]])
 #'
-#' cohortCount(cdm$drug_cohorts)
+#' cohortCount(cdm[["drug_cohorts"]])
 #'
-#' cohortAttrition(cdm$drug_cohorts)
+#' cohortAttrition(cdm[["drug_cohorts"]])
 #' }
 #'
 generateDrugUtilisationCohortSet <- function(cdm,
                                              name,
-                                             conceptSetList,
-                                             summariseMode = "AllEras",
-                                             fixedTime = NULL,
-                                             daysPriorObservation = 0,
+                                             conceptSet,
+                                             durationRange = c(1, Inf),
+                                             imputeDuration = "none",
                                              gapEra = 0,
                                              priorUseWashout = 0,
+                                             priorObservation = 0,
                                              cohortDateRange = as.Date(c(NA, NA)),
-                                             imputeDuration = "eliminate",
-                                             durationRange = c(1, Inf)) {
+                                             limit = "all") {
+  if (is.character(imputeDuration)) imputeDuration <- tolower(imputeDuration)
+  if (is.character(limit)) limit <- tolower(limit)
   checkInputs(
-    cdm = cdm,  name = name, conceptSetList = conceptSetList,
-    summariseMode = summariseMode, fixedTime = fixedTime,
-    daysPriorObservation = daysPriorObservation, gapEra = gapEra,
+    cdm = cdm, name = name, conceptSet = conceptSet,
+    limit = limit, priorObservation = priorObservation, gapEra = gapEra,
     priorUseWashout = priorUseWashout, cohortDateRange = cohortDateRange,
     imputeDuration = imputeDuration, durationRange = durationRange
   )
 
+  character <- c("imputeDuration")
+  for (char in character) {
+    if (is.character(eval(parse(text = char)))) {
+      is.character(eval(parse(text = paste0(char, " <- tolower(", char, ")"))))
+    }
+  }
+
   # get conceptSet
-  conceptSet <- conceptSetFromConceptSetList(conceptSetList)
+  conceptSet <- conceptSetFromConceptSetList(conceptSet)
 
   # generate cohort set
   cohortSetRef <- attr(conceptSet, "cohort_set") %>%
     dplyr::mutate(
-      summarise_mode = .env$summariseMode,
-      fixed_time = as.character(dplyr::coalesce(.env$fixedTime, as.numeric(NA))),
-      days_prior_observation = as.character(dplyr::coalesce(
-        .env$daysPriorObservation, as.numeric(NA)
-      )),
+      duration_range_min = as.character(.env$durationRange[1]),
+      duration_range_max = as.character(.env$durationRange[2]),
+      impute_duration = as.character(.env$imputeDuration),
       gap_era = as.character(.env$gapEra),
       prior_use_washout = as.character(.env$priorUseWashout),
+      prior_observation = as.character(dplyr::coalesce(
+        .env$priorObservation, as.numeric(NA)
+      )),
       cohort_date_range_start = as.character(.env$cohortDateRange[1]),
       cohort_date_range_end = as.character(.env$cohortDateRange[2]),
-      impute_duration = as.character(.env$imputeDuration),
-      duration_range_min = as.character(.env$durationRange[1]),
-      duration_range_max = as.character(.env$durationRange[2])
+      limit = .env$limit
     ) %>%
     insertTable(cdm, paste0(name, "_set"))
 
@@ -122,20 +121,23 @@ generateDrugUtilisationCohortSet <- function(cdm,
   attrition <- computeCohortAttrition(cohort, cdm, cohortSet = cohortSetRef)
 
   if (cohort %>% dplyr::tally() %>% dplyr::pull("n") > 0) {
-
     # correct duration
     cohort <- correctDuration(cohort, imputeDuration, durationRange, cdm)
-    reason <- paste(
-      "Duration imputation; affected rows:", attr(cohort, "numberImputations")
+    imputeCounts <- attr(cohort, "impute")
+    reason1 <- paste0(
+      "Duration imputation; affected rows: ", imputeCounts[1], " (",
+      round(imputeCounts[2]), "%)"
     )
     attrition <- computeCohortAttrition(
-      cohort, cdm, attrition, reason, cohortSet = cohortSetRef
+      cohort, cdm, attrition, reason1,
+      cohortSet = cohortSetRef
     )
 
     # eliminate overlap
     cohort <- unionCohort(cohort, gapEra, cdm)
     attrition <- computeCohortAttrition(
-      cohort, cdm, attrition, "Join eras", cohortSet = cohortSetRef
+      cohort, cdm, attrition, "Join eras",
+      cohortSet = cohortSetRef
     )
 
     # require priorUseWashout
@@ -143,16 +145,18 @@ generateDrugUtilisationCohortSet <- function(cdm,
     attrition <- computeCohortAttrition(
       cohort, cdm, attrition, paste0(
         "prior use wahout of ", priorUseWashout, " days"
-      ), cohortSet = cohortSetRef
+      ),
+      cohortSet = cohortSetRef
     )
 
-    # require daysPriorObservation
-    if (!is.null(daysPriorObservation)) {
-      cohort <- requireDaysPriorObservation(cohort, cdm, daysPriorObservation)
+    # require priorObservation
+    if (!is.null(priorObservation)) {
+      cohort <- requirePriorObservation(cohort, cdm, priorObservation)
       attrition <- computeCohortAttrition(
         cohort, cdm, attrition, paste0(
-          "at least ", daysPriorObservation, " prior observation"
-        ), cohortSet = cohortSetRef
+          "at least ", priorObservation, " prior observation"
+        ),
+        cohortSet = cohortSetRef
       )
     }
 
@@ -161,7 +165,8 @@ generateDrugUtilisationCohortSet <- function(cdm,
     attrition <- computeCohortAttrition(
       cohort, cdm, attrition, paste0(
         "cohort_start_date >= ", cohortDateRange[1]
-      ), cohortSet = cohortSetRef
+      ),
+      cohortSet = cohortSetRef
     )
 
     # trim end date
@@ -169,16 +174,19 @@ generateDrugUtilisationCohortSet <- function(cdm,
     attrition <- computeCohortAttrition(
       cohort, cdm, attrition, paste0(
         "cohort_end_date <= ", cohortDateRange[2]
-      ), cohortSet = cohortSetRef
-    )
-
-    # apply summariseMode
-    cohort <- applySummariseMode(cohort, cdm, summariseMode, fixedTime)
-    attrition <- computeCohortAttrition(
-      cohort, cdm, attrition, paste("summariseMode:", summariseMode, "applied"),
+      ),
       cohortSet = cohortSetRef
     )
 
+    # apply limit
+    if (limit == "first") {
+      cohort <- applyLimit(cohort, cdm, limit)
+      attrition <- computeCohortAttrition(
+        cohort, cdm, attrition, "Limit to first era",
+        cohortSet = cohortSetRef
+      )
+    }
+
   }
 
   # create the cohort references
@@ -197,7 +205,8 @@ generateDrugUtilisationCohortSet <- function(cdm,
       FALSE, attr(cdm, "write_schema"), TRUE
     )
   cohortCountRef <- computeCohortCount(
-    cohort, cdm, cohortSet = cohortSetRef
+    cohort, cdm,
+    cohortSet = cohortSetRef
   ) %>%
     CDMConnector::computeQuery(
       name = paste0(attr(cdm, "write_prefix"), name, "_count"),
@@ -210,11 +219,7 @@ generateDrugUtilisationCohortSet <- function(cdm,
     cohortSetRef = cohortSetRef,
     cohortAttritionRef = cohortAttritionRef,
     cohortCountRef = cohortCountRef
-
   )
 
-  #add cdm_reference as attribute
-  attr(cdm[[name]], "cdm_reference") <- cdm
-
   return(cdm)
 }
